summaryrefslogtreecommitdiff
path: root/test/unit/parser/parser_builder_black.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/parser/parser_builder_black.cpp')
-rw-r--r--test/unit/parser/parser_builder_black.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/unit/parser/parser_builder_black.cpp b/test/unit/parser/parser_builder_black.cpp
index 08b16dd07..3ebd11b83 100644
--- a/test/unit/parser/parser_builder_black.cpp
+++ b/test/unit/parser/parser_builder_black.cpp
@@ -9,9 +9,9 @@
** All rights reserved. See the file COPYING in the top-level source
** directory for licensing information.\endverbatim
**
** \brief Black box testing of CVC4::parser::ParserBuilder.
**
** Black box testing of CVC4::parser::ParserBuilder.
**/
#include <stdio.h>
@@ -29,7 +29,7 @@
#include "parser/parser_builder.h"
#include "test_api.h"
-namespace CVC4 {
+namespace CVC5 {
using namespace parser;
using namespace language::input;
@@ -134,4 +134,4 @@ TEST_F(TestParseBlackParserBuilder, true_stream_input)
}
} // namespace test
-} // namespace CVC4
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -9,9 +9,9 @@
** directory for licensing information.\endverbatim
**
- ** \brief Black box testing of CVC4::parser::ParserBuilder.
+ ** \brief Black box testing of CVC5::parser::ParserBuilder.
**
@@ -9,9 +9,9 @@
**
- ** Black box testing of CVC4::parser::ParserBuilder.
+ ** Black box testing of CVC5::parser::ParserBuilder.
**/
#include <stdio.h>